==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressMemorySpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StressMemorySpecFluentImpl<A extends StressMemorySpecFluent<A>> extends BaseFluent<A> implements StressMemorySpecFluent<A>{
  public StressMemorySpecFluentImpl() {
  }
  public StressMemorySpecFluentImpl(StressMemorySpec instance) {
    this.withOptions(instance.getOptions()); 
    this.withSize(instance.getSize()); 
  }
  private String options;
  private String size;
  public String getOptions() {
    return this.options;
  }
  public A withOptions(String options) {
    this.options=options; return (A) this;
  }
  public Boolean hasOptions() {
    return this.options != null;
  }
  public String getSize() {
    return this.size;
  }
  public A withSize(String size) {
    this.size=size; return (A) this;
  }
  public Boolean hasSize() {
    return this.size != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StressMemorySpecFluentImpl that = (StressMemorySpecFluentImpl) o;
    if (options != null ? !options.equals(that.options) :that.options != null) return false;
    if (size != null ? !size.equals(that.size) :that.size != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(options,  size,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (options != null) { sb.append("options:"); sb.append(options + ","); }
    if (size != null) { sb.append("size:"); sb.append(size); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressMemorySpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StressMemorySpecFluentImpl<A extends StressMemorySpecFluent<A>> extends BaseFluent<A> implements StressMemorySpecFluent<A>{
  public StressMemorySpecFluentImpl() {
  }
  public StressMemorySpecFluentImpl(StressMemorySpec instance) {
    if (instance != null) {
      this.withOptions(instance.getOptions());
      this.withSize(instance.getSize());
    }
  }
  private String options;
  private String size;
  public String getOptions() {
    return this.options;
  }
  public A withOptions(String options) {
    this.options=options; return (A) this;
  }
  public Boolean hasOptions() {
    return this.options != null;
  }
  public String getSize() {
    return this.size;
  }
  public A withSize(String size) {
    this.size=size; return (A) this;
  }
  public Boolean hasSize() {
    return this.size != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StressMemorySpecFluentImpl that = (StressMemorySpecFluentImpl) o;
    if (!java.util.Objects.equals(options, that.options)) return false;

    if (!java.util.Objects.equals(size, that.size)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(options,  size,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (options != null) { sb.append("options:"); sb.append(options + ","); }
    if (size != null) { sb.append("size:"); sb.append(size); }
    sb.append("}");
    return sb.toString();
  }
  
}
